@@ -49,7 +49,7 @@ use warnings; no warnings qw(redefine);
 
 package RT::Extension::MergeUsers;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 NAME
 
@@ -289,8 +289,8 @@ sub SetEmailAddress {
     my $self = shift;
     my $value = shift;
 
-    return ( 0, $self->loc('Email address in use') )
-        unless $self->ValidateEmailAddress( $value );
+    my ( $val, $msg ) = $self->ValidateEmailAddress($value);
+    return ( 0, $msg || $self->loc('Email address in use') ) unless $val;
 
     # if value is valid then either there is no user or
     # user is merged into this one
